==> v1.2019.0.tar.gz: plantuml/src/net/sourceforge/plantuml/project3/LoadInDays.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2020, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.project3;

public class LoadInDays implements Load {

	private final int days;
	private final int loadPerDay;

	private LoadInDays(int days, int loadPerDay) {
		this.days = days;
		this.loadPerDay = loadPerDay;
	}

	public static LoadInDays inDay(int days) {
		return new LoadInDays(days, 100);
	}

	public static Complement inDayWithLoad(int days, int loadPerDay) {
		final int tmp = (int) Math.ceil(days * 100.0 / loadPerDay);
		return new LoadInDays(tmp, loadPerDay);
	}

	public int getFullLoad() {
		return days * loadPerDay;
	}

	public int getLoadAt(Instant instant) {
		return loadPerDay;
	}

}

==> v1.2019.2.tar.gz: plantuml/src/net/sourceforge/plantuml/project3/LoadInDays.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2020, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.project3;

public class LoadInDays implements Load {

	private final int days;
	private final int loadPerDay;

	private LoadInDays(int days, int loadPerDay) {
		this.days = days;
		this.loadPerDay = loadPerDay;
	}

	public static LoadInDays inDay(int days) {
		return new LoadInDays(days, 100);
	}

//	public static Complement inDayWithLoad(int days, int loadPerDay) {
//		final int tmp = (int) Math.ceil(days * 100.0 / loadPerDay);
//		return new LoadInDays(tmp, loadPerDay);
//	}

	public int getFullLoad() {
		return days * loadPerDay;
	}

	public int getLoadAt(Instant instant) {
		return loadPerDay;
	}

}
